<?xml version='1.0' encoding='UTF-8'?><!-- -*- indent-tabs-mode: nil -*- -->
<!--
Copyright (c) 2006 Goran Rakic <grakic@devbase.net>.

This file is part of libgo.

libgo is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

libgo is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with libgo; if not, write to the Free Software Foundation, Inc.,
59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		        xmlns:doc="http://www.gnome.org/~shaunm/xsldoc"
                xmlns:exsl="http://exslt.org/common"
                xmlns="http://www.w3.org/1999/xhtml"
		        exclude-result-prefixes="doc"
                extension-element-prefixes="exsl"
                version="1.0">

<!-- FIXME: Shaun's styles are under LGPL, is it OK to use GPL for this? -->
<!-- <xsl:import href="/usr/share/xml/gnome/xslt/docbook/html/db2html.xsl"/> -->
<xsl:import href="/usr/local/src/gnome/gnome-doc-utils/xslt/docbook/html/db2html.xsl"/>

<doc:title>Convert DocBook to libgo's XHTML output</doc:title>

<!-- This gets set on the command line ... -->
<xsl:param name="libgo.lang" select="''"/>

<!-- don't include linktrail -->
<xsl:param name="db2html.linktrail" select="false()"/>


<!-- Setting parameters for included stylesheets -->
<xsl:param name="db.chunk.extension" select="concat('.html.',$libgo.lang)" doc:private="true"/>
<xsl:param name="db.chunk.info_basename" select="'index'" />

<!-- Get abstract/title -->
<xsl:template name="libgo.info.abstract">
  <xsl:param name="node" select="."/>
  <xsl:param name="info" select="'FIXME'"/>
    <xsl:apply-templates mode="db2html.info.mode"
                         select="$info/abstract/node()"/>
</xsl:template>
<xsl:template name="libgo.info.title">
  <xsl:param name="node" select="."/>
  <xsl:param name="info" select="'FIXME'"/>
    <xsl:apply-templates mode="db2html.info.mode"
                         select="$info/title/node()"/>
</xsl:template>

  
<!-- Create XML index file -->
<xsl:template name="libgo.indexfile">
    <xsl:param name="info" select="'FIXME'"/>
    <xsl:param name="title">
        <xsl:call-template name="libgo.info.title">
            <xsl:with-param name="info" select="$info"/>
        </xsl:call-template>
    </xsl:param>  
    <xsl:param name="abstract">
        <xsl:call-template name="libgo.info.abstract">
            <xsl:with-param name="info" select="$info"/>
        </xsl:call-template>
    </xsl:param>  
    <exsl:document href="{concat('index.xml.',$libgo.lang)}" indent="yes" >
    <document>
      <title>
        <xsl:value-of select="normalize-space($title)" />
      </title>
      <abstract>
        <xsl:value-of select="normalize-space($abstract)" />
      </abstract>
    </document>
    </exsl:document>    
</xsl:template>


<!-- == db2html.division.html ============================================= -->
<xsl:template name="db2html.division.html">
  <xsl:param name="node" select="."/>
  <xsl:param name="info"/>
  <xsl:param name="depth_of_chunk">
    <xsl:call-template name="db.chunk.depth-of-chunk">
      <xsl:with-param name="node" select="$node"/>
    </xsl:call-template>
  </xsl:param>
  <xsl:variable name="prev_id">
    <xsl:choose>
      <xsl:when test="$depth_of_chunk = 0">
        <xsl:if test="$info">
          <xsl:value-of select="$db.chunk.info_basename"/>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="db.chunk.chunk-id.axis">
          <xsl:with-param name="node" select="$node"/>
          <xsl:with-param name="axis" select="'previous'"/>
          <xsl:with-param name="depth_in_chunk" select="0"/>
          <xsl:with-param name="depth_of_chunk" select="$depth_of_chunk"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="next_id">
    <xsl:call-template name="db.chunk.chunk-id.axis">
      <xsl:with-param name="node" select="$node"/>
      <xsl:with-param name="axis" select="'next'"/>
      <xsl:with-param name="depth_in_chunk" select="0"/>
      <xsl:with-param name="depth_of_chunk" select="$depth_of_chunk"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="prev_node" select="key('idkey', $prev_id)"/>
  <xsl:variable name="next_node" select="key('idkey', $next_id)"/>
  <!-- FIXME -->
  <html>
    <head>
      <title>
        <xsl:variable name="title">
          <xsl:call-template name="db.title">
            <xsl:with-param name="node" select="$node"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select="normalize-space($title)"/>
      </title>
      <link rel="stylesheet" type="text/css" href="/lgo.css" />
      <xsl:if test="string($prev_id) != ''">
        <link rel="previous">
          <xsl:attribute name="href">
            <xsl:call-template name="db.xref.target">
              <xsl:with-param name="linkend" select="$prev_id"/>
              <xsl:with-param name="target" select="$prev_node"/>
              <xsl:with-param name="is_chunk" select="true()"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:call-template name="db.title">
              <xsl:with-param name="node" select="$prev_node"/>
            </xsl:call-template>
          </xsl:attribute>
        </link>
      </xsl:if>
      <xsl:if test="string($next_id) != ''">
        <link rel="next">
          <xsl:attribute name="href">
            <xsl:call-template name="db.xref.target">
              <xsl:with-param name="linkend" select="$next_id"/>
              <xsl:with-param name="target" select="$next_node"/>
              <xsl:with-param name="is_chunk" select="true()"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:call-template name="db.title">
              <xsl:with-param name="node" select="$next_node"/>
            </xsl:call-template>
          </xsl:attribute>
        </link>
      </xsl:if>
      <xsl:if test="/*[1] != $node">
        <link rel="top">
          <xsl:attribute name="href">
            <xsl:call-template name="db.xref.target">
              <xsl:with-param name="linkend" select="/*[1]/@id"/>
              <xsl:with-param name="target" select="/*[1]"/>
              <xsl:with-param name="is_chunk" select="true()"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:call-template name="db.title">
              <xsl:with-param name="node" select="/*[1]"/>
            </xsl:call-template>
          </xsl:attribute>
        </link>
      </xsl:if>

      <!-- FIXME: Replace this with libgo.css -->
      <!-- <xsl:call-template name="db2html.css"/>      -->
      <xsl:call-template name="db2html.division.head.extra"/>

    </head>
    <body>
      <xsl:comment>
        <xsl:text>#include virtual="/header.html.en"</xsl:text>
      </xsl:comment>


      <!-- FIXME: Sidebar and table of content are missing -->
      <xsl:call-template name="db2html.division.navbar">
        <xsl:with-param name="node" select="$node"/>
        <xsl:with-param name="info" select="$info"/>
        <xsl:with-param name="depth_of_chunk" select="$depth_of_chunk"/>
        <xsl:with-param name="prev_id" select="$prev_id"/>
        <xsl:with-param name="next_id" select="$next_id"/>
        <xsl:with-param name="prev_node" select="$prev_node"/>
        <xsl:with-param name="next_node" select="$next_node"/>
      </xsl:call-template>

      <div class="body">
        <xsl:apply-templates select="$node">
          <xsl:with-param name="depth_in_chunk" select="0"/>
          <xsl:with-param name="depth_of_chunk" select="$depth_of_chunk"/>
        </xsl:apply-templates>
      </div>

      <div id="sidebar">
       <h2><xsl:value-of select="//title" /></h2>
       <ul id="toc">
        <xsl:apply-templates mode="db.chunk.content.toc" select="//sect1"/>
       </ul>
      </div>

      <xsl:comment>
        <xsl:text>#include virtual="/footer.html.en"</xsl:text>
      </xsl:comment>
    </body>
  </html>
</xsl:template>

<xsl:template mode="db.chunk.content.toc" match="sect1">
 <li><a>
   <xsl:attribute name="href">
     <xsl:value-of select="concat(@id, $db.chunk.extension)"/>
   </xsl:attribute>
   <xsl:value-of select="title" /></a></li>
</xsl:template>

<!-- == db2html.info ====================================================== -->
<xsl:template name="db2html.info">
  <xsl:param name="node" select="." />
  <xsl:param name="info" select="'FIXME'"/>

  <html>
    <head>
      <!-- FIXME: Replace this with libgo.css -->  
      <link rel="stylesheet" type="text/css" href="/lgo.css" />
    </head>
    <body>
      <xsl:comment>
        <xsl:text>#include virtual="/header.html.en"</xsl:text>
      </xsl:comment>
    
     <!-- FIXME: Sidebar and table of content are missing -->
      <div class="body">
        <div class="{local-name($info)}">
          <xsl:call-template name="db2html.anchor">
            <xsl:with-param name="name" select="local-name($info)"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.title">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.subtitle">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <h3 class="abstract">
            <xsl:call-template name="libgo.info.abstract">
              <xsl:with-param name="node" select="$node"/>
              <xsl:with-param name="info" select="$info"/>
            </xsl:call-template>
          </h3>
          <xsl:call-template name="db2html.info.authors">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.editors">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.collabs">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.translators">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.publishers">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.othercredits">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:call-template name="db2html.info.copyrights">
            <xsl:with-param name="node" select="$node"/>
            <xsl:with-param name="info" select="$info"/>
          </xsl:call-template>
          <xsl:apply-templates mode="db2html.info.mode" select="$info/legalnotice"/>
          <xsl:apply-templates mode="db2html.info.mode" select="$info/revhistory"/>
        </div>
      </div>

      <div id="sidebar">
       <h2><xsl:value-of select="//title" /></h2>
       <ul id="toc">
        <xsl:apply-templates mode="db.chunk.content.toc" select="//sect1"/>
       </ul>
      </div>

      <xsl:comment>
        <xsl:text>#include virtual="/footer.html.en"</xsl:text>
      </xsl:comment>
    </body>
  </html>
</xsl:template>

<xsl:template name="db2html.info.subtitle">
  <xsl:param name="node" select="."/>
  <xsl:param name="info" select="'FIXME'"/>
  <xsl:choose>
    <xsl:when test="$info/subtitle">
      <h2>
        <xsl:apply-templates mode="db2html.info.mode"
                             select="$info/subtitle/node()"/>
      </h2>
    </xsl:when>
    <xsl:when test="$node/subtitle">
      <h2>
        <xsl:apply-templates mode="db2html.info.mode"
                             select="$node/subtitle/node()"/>
      </h2>
    </xsl:when>
  </xsl:choose>
</xsl:template>


<!-- Process -->
<xsl:template match="/">
    <xsl:call-template name="libgo.indexfile">
      <xsl:with-param name="info" select="article/articleinfo|book/bookinfo"/>
    </xsl:call-template>
    <xsl:call-template name="db.chunk.children">
      <xsl:with-param name="node" select="*"/>
      <xsl:with-param name="depth_of_chunk" select="0"/>
    </xsl:call-template>
</xsl:template>


<!--**==========================================================================
db2html.division.navbar
FIXME

REMARK: Document this template
-->
<!-- XXX: straight from older gnome-doc-utils -->
<xsl:template name="db2html.division.navbar">
  <xsl:param name="node"/>
  <xsl:param name="info"/>
  <xsl:param name="depth_of_chunk">
    <xsl:call-template name="db.chunk.depth-of-chunk">
      <xsl:with-param name="node" select="$node"/>
    </xsl:call-template>
  </xsl:param>
  <xsl:param name="prev_id">
    <xsl:choose>
      <xsl:when test="$depth_of_chunk = 0 and $info">
        <xsl:if test="$info">
          <xsl:value-of select="$db.chunk.info_basename"/>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="db.chunk.chunk-id.axis">
          <xsl:with-param name="node" select="$node"/>
          <xsl:with-param name="axis" select="'previous'"/>
          <xsl:with-param name="depth_in_chunk" select="0"/>
          <xsl:with-param name="depth_of_chunk" select="$depth_of_chunk"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="next_id">
    <xsl:call-template name="db.chunk.chunk-id.axis">
      <xsl:with-param name="node" select="$node"/>
      <xsl:with-param name="axis" select="'next'"/>
      <xsl:with-param name="depth_in_chunk" select="0"/>
      <xsl:with-param name="depth_of_chunk" select="$depth_of_chunk"/>
    </xsl:call-template>
  </xsl:param>
  <xsl:param name="prev_node" select="key('idkey', $prev_id)"/>
  <xsl:param name="next_node" select="key('idkey', $next_id)"/>
  <div class="navbar">
    <xsl:if test="($info and $depth_of_chunk = 0) or $prev_node">
      <xsl:variable name="class">
        <xsl:text>navbar-prev</xsl:text>
        <xsl:if test="not($next_node)">
          <xsl:text> navbar-prev-sans-next</xsl:text>
        </xsl:if>
      </xsl:variable>
      <div class="{$class}">
        <span class="{$class}">
	&#8592;
          <a class="navbar {$class}">
            <xsl:attribute name="href">
              <xsl:call-template name="db.xref.target">
                <xsl:with-param name="linkend" select="$prev_id"/>
                <xsl:with-param name="is_chunk" select="true()"/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:choose>
              <xsl:when test="$depth_of_chunk = 0">
                <!-- FIXME: don't use db.label for this -->
                <xsl:variable name="label">
                  <xsl:call-template name="db.label">
                    <xsl:with-param name="node" select="$info"/>
                  </xsl:call-template>
                </xsl:variable>
                <xsl:attribute name="title">
                  <xsl:value-of select="normalize-space($label)"/>
                </xsl:attribute>
                <xsl:value-of select="$label"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:attribute name="title">
                  <xsl:call-template name="db.xref.tooltip">
                    <xsl:with-param name="linkend" select="$prev_id"/>
                    <xsl:with-param name="target"  select="$prev_node"/>
                  </xsl:call-template>
                </xsl:attribute>
                <xsl:call-template name="db.titleabbrev">
                  <xsl:with-param name="node" select="$prev_node"/>
                </xsl:call-template>
              </xsl:otherwise>
            </xsl:choose>
          </a>
        </span>
      </div>
    </xsl:if>
    <xsl:if test="$next_node">
      <xsl:variable name="class">
        <xsl:text>navbar-next</xsl:text>
        <xsl:if test="not($prev_node)">
          <xsl:text> navbar-next-sans-prev</xsl:text>
        </xsl:if>
      </xsl:variable>
      <div class="{$class}">
        <span class="{$class}">
          <a class="navbar {$class}">
            <xsl:attribute name="href">
              <xsl:call-template name="db.xref.target">
                <xsl:with-param name="linkend" select="$next_id"/>
                <xsl:with-param name="is_chunk" select="true()"/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="title">
              <xsl:call-template name="db.xref.tooltip">
                <xsl:with-param name="linkend" select="$next_id"/>
                <xsl:with-param name="target"  select="$next_node"/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:call-template name="db.titleabbrev">
              <xsl:with-param name="node" select="$next_node"/>
            </xsl:call-template>
          </a>
	&#8594;
        </span>
      </div>
    </xsl:if>
  </div>
</xsl:template>



</xsl:stylesheet>
